@@ -12,21 +12,17 @@ fn main() {
     let start_time = Local::now();
 
     // get the argument inputs
-    let mut args = barcode_count::Args::new().unwrap_or_else(|err| panic!("Argument error: {}", err));
+    let mut args =
+        barcode_count::Args::new().unwrap_or_else(|err| panic!("Argument error: {}", err));
 
     let sequence_format = barcode_count::info::SequenceFormat::new(args.format.clone())
         .unwrap_or_else(|err| panic!("sequence format error: {}", err));
     println!("{}\n", sequence_format);
 
     // Check how many barcodes occur if either single or double barcode enrichment is callsed.  If there are too few, ignore the argument flag
-    if args.single_barcode_enrichment && sequence_format.barcode_num < 2 {
-        eprintln!("Fewer than 2 counted barcodes.  Too few for single barcode enrichment.  Argument flag is ignored");
-        args.single_barcode_enrichment = false;
-    }
-
-    if args.double_barcode_enrichment && sequence_format.barcode_num < 3 {
-        eprintln!("Fewer than 3 counted barcodes.  Too few for double barcode enrichment.  Argument flag is ignored");
-        args.double_barcode_enrichment = false;
+    if args.enrich && sequence_format.barcode_num < 2 {
+        eprintln!("Fewer than 2 counted barcodes.  Too few for barcode enrichment.  Argument flag is ignored");
+        args.enrich = false;
     }
 
     // Start getting the barcode conversion with the BarcodeConversions struct
@@ -96,7 +92,8 @@ fn main() {
             finished_clone.store(true, Ordering::Relaxed);
         });
 
-        let shared_mut = barcode_count::parse::SharedMutData::new(seq, finished, Arc::clone(&results));
+        let shared_mut =
+            barcode_count::parse::SharedMutData::new(seq, finished, Arc::clone(&results));
         // Create processing threads.  One less than the total threads because of the single reading thread
         for _ in 1..args.threads {
             // Clone all variables needed to pass into each thread
